==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_context_folder.js <==
_me = obj_context_folder.prototype;
function obj_context_folder(){};

_me._onclick = function(e,elm,id,arg){
	var me = this;

	if (!arg) return;

	switch(arg['method'])
	{
		case 'add_folder':
			gui._create('frm_add_folder','frm_add_folder','','',arg.aid,arg.fid);
			break;

		case 'delete_folder':
			if (WMFolders.getRights(arg,'remove'))
				gui._create('frm_confirm','frm_confirm','','',[me, '__deleteFolder', [arg.aid, arg.fid]],'CONFIRMATION::DELETE_FOLDER_CONFIRMATION','CONFIRMATION::DELETE_FOLDER',[Path.basename(arg['fid'])]);
			else
				alert(getLang('CONTEXT_FOLDER::CANTDELETE'));
			break;

		case 'move_folder':
			if (WMFolders.getRights(arg,'modify'))
				gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::MOVE_FOLDER',arg['aid'],arg['fid'],[this,'__moveFolder',[arg['fid']]],false,true);
			else
				alert(getLang('CONTEXT_FOLDER::CANTMOVE'));
			break;

		case 'empty_folder':
			var sFullPath = arg['aid'] + '/' + arg['fid'];
			var sTrashFolder = GWOthers.getItem('DEFAULT_FOLDERS', 'trash');

			if (sFullPath == sTrashFolder || parseInt(GWOthers.getItem('MAIL_SETTINGS_GENERAL', 'delete_emptyfolder'))>0) {
				gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
					[arg['aid'], arg['fid']]],
					'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_FOLDER'
				);
			} else {
				gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
					[arg['aid'], arg['fid'], true]],
					'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_TO_TRASH'
				);
			}

			break;
			
		case 'mark_all_as_read':
		case 'mark_all_as_unread':
			var bRead = arg['method'] == 'mark_all_as_read' ? true : false;
			WMFolders.markItemsRead({'aid':arg.aid,'fid':arg.fid},'folders','',bRead);
			break;

		case 'rename_folder':
			if (WMFolders.getRights(arg,'modify'))
			{
				var oFolders = gui.frm_main.folders;

				// some istance already exists
				if (oFolders.rename) oFolders.rename._onclose();

				var sLiId   = oFolders._pathName+'/'+arg.aid + (arg.fid?'/'+arg.fid:'');
				var hDiv    = document.getElementById(sLiId).getElementsByTagName('DIV')[0];
				var hLink   = document.getElementById(sLiId).getElementsByTagName('A')[0];

				// aby se neprekresloval tree!!
				oFolders._norefresh = true;

				// hide link
				var oldStyle = hLink.style.display;
				hLink.style.display = 'none';

				// create editDiv anchor and ID to hDiv
				var sAnchor = sLiId + 'editDiv';
				oFolders._anchors['editDiv'] = sAnchor;
				hDiv.id = sAnchor;

				// create obj_input in oFolders' editDiv anchor
				oFolders._create('rename','obj_input','editDiv');
				// remove anchor immediately (better solution)
				delete oFolders._anchors['editDiv'];

				// set value
				var nPos = arg.fid.lastIndexOf('/');
				var sParentName = arg.fid.substring(0,nPos);
				var sFolderName = arg.fid.substring(nPos + 1);

				oFolders.rename._value(sFolderName);

				// set focus on object
				oFolders.rename._focus();

				oFolders.rename._onsubmit = function(e)
				{
					var snew = this._value();
					var sold = sFolderName;

					if (sold == snew){
						this._onclose();
						return;
					}

					var folders = new wm_folders;
					var sNewFolderID = (sParentName ? sParentName + '/' : '') +snew;

					folders.add({'aid': arg.aid, 'fid': arg.fid, 'name': sNewFolderID, 'type': arg.ftype}, 'folders');

					/*    mozna zapsat do name + refresh, a pak async refresh kterej uz bude ok
					
					var aData = dataSet.get('folders', [arg.aid, arg.fid]);
					dataSet.add('folders', [arg.aid, sNewFolderID], aData, true);
					dataSet.remove('folders', [arg.aid, arg.fid], true);
					*/

					this._onclose();
				};

				oFolders.rename._onclose = function(e){

					if (this._destructed) return false;

					// aby se zase prekresloval tree
					oFolders._norefresh = false;
					if (oFolders._updateBuffer)
						oFolders.__update('folders');

					// zrusit input objekt
					this._destruct();
					hLink.style.display = oldStyle;
				}
				
				oFolders.rename._onblur = oFolders.rename._onclose;
			}
			else
				alert(getLang('CONTEXT_FOLDER::CANTRENAME'));

		//gui._create('frm_rename_folder', 'frm_rename_folder', '', '', arg.aid, arg.fid);
		break;
	}
};

_me.__deleteFolder = function(sAccountID,sFolderID)
{
	var folders = new wm_folders();
	folders.remove({'aid':sAccountID,'fid':sFolderID},'folders');

	var aFolders = dataSet.get('folders',[sAccountID]);
	var bPerfm = false;
	for(var i in aFolders){
		if (i == sFolderID || i.indexOf(sFolderID+'/') === 0){
            bPerfm = true;
			delete aFolders[i];
		}
	}

	//	bNoRefresh = true protoze pracujeme primo s datasetem, proto po add neni zmena dat (add je jen pro sychr)
    //	Notne vyvolat refresh manualne
	if(bPerfm){
		dataSet.add('folders',[sAccountID],aFolders,true);
		dataSet.update('folders',[sAccountID]);
	}

	var aItems = dataSet.get('items');
	for(var sAccId in aItems)
		for(var sFolId in aItems[sAccId]);

	if (sAccId == sAccountID && sFolId == sFolderID)
	{
		if (gui.frm_main.main)
			gui.frm_main.main._destruct();

		gui.frm_main._lastView = '';
		gui.frm_main.hmenu3._fill();

		dataSet.remove('items');
		dataSet.remove('mailview');
	}
};

_me.__moveFolder = function(sAccount,sNewFolder,sOldFolder){
	sNewFolder = (sNewFolder?sNewFolder + '/':'') + Path.basename(sOldFolder);

	gui.frm_main.folders._invalidateActive();

	var folders = new wm_folders;
	folders.add({'aid':sAccount,'fid':sOldFolder,'name':sNewFolder},'folders');
};

_me.__deleteAccount = function(sAccId)
{
	var accounts = new wm_accounts;
	accounts.remove({'aid':sAccId},'accounts','','folders');
	
	//Remove account from dataSet
	dataSet.remove('accounts',[sAccId]);
	dataSet.remove('folders',[sAccId]);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_context_folder.js <==
_me = obj_context_folder.prototype;
function obj_context_folder(){};

_me._onclick = function(e,elm,id,arg){
	var me = this;

	if (!arg) return;

	switch(arg['method'])
	{
		case 'add_folder':
			gui._create('frm_add_folder','frm_add_folder','','',arg.aid,arg.fid);
			break;

		case 'delete_folder':
			if (WMFolders.getRights(arg,'remove'))
				gui._create('frm_confirm','frm_confirm','','',[me, '__deleteFolder', [arg.aid, arg.fid]],'CONFIRMATION::DELETE_FOLDER_CONFIRMATION','CONFIRMATION::DELETE_FOLDER',[Path.basename(arg['fid'])]);
			else
				alert(getLang('CONTEXT_FOLDER::CANTDELETE'));
			break;

		case 'move_folder':
			if (WMFolders.getRights(arg,'modify'))
				gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::MOVE_FOLDER',arg['aid'],arg['fid'],[this,'__moveFolder',[arg['fid']]],false,true);
			else
				alert(getLang('CONTEXT_FOLDER::CANTMOVE'));
			break;

		case 'empty_folder':
			var sFullPath = arg['aid'] + '/' + arg['fid'];
			var sTrashFolder = GWOthers.getItem('DEFAULT_FOLDERS', 'trash');
			var sFolderType = dataSet.get('folders',[arg['aid'],arg['fid'],'TYPE']);

			if (sFullPath == sTrashFolder || sFolderType == 'R' || parseInt(GWOthers.getItem('MAIL_SETTINGS_GENERAL', 'delete_emptyfolder'))>0)
				gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
					[arg['aid'], arg['fid']]],
					'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_FOLDER'
				);
			else
				gui._create('frm_confirm', 'frm_confirm', '', '',[WMFolders, '__emptyFolder',
					[arg['aid'], arg['fid'], true]],
					'CONFIRMATION::EMPTY_FOLDER_CONFIRMATION', 'CONFIRMATION::EMPTY_TO_TRASH'
				);


			break;
			
		case 'mark_all_as_read':
		case 'mark_all_as_unread':
			var bRead = arg['method'] == 'mark_all_as_read' ? true : false;
			WMFolders.markItemsRead({'aid':arg.aid,'fid':arg.fid},'folders','',bRead);
			break;

        case 'change_channel':
            gui._create('frm_change_channel','frm_change_channel','','',arg.aid,arg.fid);
            break;
            
		case 'rename_folder':
			if (WMFolders.getRights(arg,'modify'))
			{
				var oFolders = gui.frm_main.folders;

				// some istance already exists
				if (oFolders.rename) oFolders.rename._onclose();

				var sLiId   = oFolders._pathName+'/'+arg.aid + (arg.fid?'/'+arg.fid:'');
				var hDiv    = document.getElementById(sLiId).getElementsByTagName('DIV')[0];
				var hLink   = document.getElementById(sLiId).getElementsByTagName('A')[0];

				// aby se neprekresloval tree!!
				oFolders._norefresh = true;

				// hide link
				var oldStyle = hLink.style.display;
				hLink.style.display = 'none';

				// create editDiv anchor and ID to hDiv
				var sAnchor = sLiId + 'editDiv';
				oFolders._anchors['editDiv'] = sAnchor;
				hDiv.id = sAnchor;

				// create obj_input in oFolders' editDiv anchor
				var rinput = oFolders._create('rename','obj_input','editDiv');
				    rinput._restrict('![/\\\\:\*\?\"\<\>\|\~]+','','.+');
				
				// remove anchor immediately (better solution)
				delete oFolders._anchors['editDiv'];

				// set value
				var nPos = arg.fid.lastIndexOf('/');
				var sParentName = arg.fid.substring(0,nPos);
				var sFolderName = arg.fid.substring(nPos + 1);

				rinput._value(sFolderName);

				// set focus on object
				rinput._focus();

				rinput._onsubmit = function(e)
				{
					if (this._checkError && this._checkError.length) return;

					var snew = this._value();
					var sold = sFolderName;

					if (sold == snew){
						this._onclose();
						return;
					}

					var folders = new wm_folders;
					var sNewFolderID = (sParentName ? sParentName + '/' : '') +snew;

					folders.add({'aid': arg.aid, 'fid': arg.fid, 'name': sNewFolderID, 'type': arg.ftype}, 'folders');

					/*    mozna zapsat do name + refresh, a pak async refresh kterej uz bude ok
					
					var aData = dataSet.get('folders', [arg.aid, arg.fid]);
					dataSet.add('folders', [arg.aid, sNewFolderID], aData, true);
					dataSet.remove('folders', [arg.aid, arg.fid], true);
					*/

					this._onclose();
				};

				oFolders.rename._onclose = function(e){

					if (this._destructed) return false;

					// aby se zase prekresloval tree
					oFolders._norefresh = false;
					if (oFolders._updateBuffer)
						oFolders.__update('folders');

					// zrusit input objekt
					this._destruct();
					hLink.style.display = oldStyle;
				}
				
				oFolders.rename._onblur = oFolders.rename._onclose;
			}
			else
				alert(getLang('CONTEXT_FOLDER::CANTRENAME'));

		//gui._create('frm_rename_folder', 'frm_rename_folder', '', '', arg.aid, arg.fid);
		break;
	}
};

_me.__deleteFolder = function(sAccountID,sFolderID)
{
	var folders = new wm_folders();
	folders.remove({'aid':sAccountID,'fid':sFolderID},'folders');

	var aFolders = dataSet.get('folders',[sAccountID]);
	var bPerfm = false;
	for(var i in aFolders){
		if (i == sFolderID || i.indexOf(sFolderID+'/') === 0){
            bPerfm = true;
			delete aFolders[i];
		}
	}

	//	bNoRefresh = true protoze pracujeme primo s datasetem, proto po add neni zmena dat (add je jen pro sychr)
    //	Notne vyvolat refresh manualne
	if(bPerfm){
		dataSet.add('folders',[sAccountID],aFolders,true);
		dataSet.update('folders',[sAccountID]);
	}

	var aItems = dataSet.get('items');
	for(var sAccId in aItems)
		for(var sFolId in aItems[sAccId]);

	if (sAccId == sAccountID && sFolId == sFolderID)
	{
		if (gui.frm_main.main)
			gui.frm_main.main._destruct();

		gui.frm_main._lastView = '';
		gui.frm_main.hmenu3._fill();

		dataSet.remove('items');
		dataSet.remove('mailview');
	}
};

_me.__moveFolder = function(sAccount,sNewFolder,sOldFolder){
	sNewFolder = (sNewFolder?sNewFolder + '/':'') + Path.basename(sOldFolder);

	gui.frm_main.folders._invalidateActive();

	var folders = new wm_folders;
	folders.add({'aid':sAccount,'fid':sOldFolder,'name':sNewFolder},'folders');
};

_me.__deleteAccount = function(sAccId)
{
	var accounts = new wm_accounts;
	accounts.remove({'aid':sAccId},'accounts','','folders');
	
	//Remove account from dataSet
	dataSet.remove('accounts',[sAccId]);
	dataSet.remove('folders',[sAccId]);
};
